@@ -82,8 +82,8 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import cdktf_cdktf_provider_google
-import constructs
+import cdktf_cdktf_provider_google as _cdktf_cdktf_provider_google_6cd2ae20
+import constructs as _constructs_77d1e7e8
 
 
 @jsii.data_type(
@@ -104,10 +104,10 @@ class DockerVolumes:
         :param host_path: EC2 Runner Host Path.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DockerVolumes.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__30cc7f3d151088ac92608a86463900f48e86489ed15b894a78018b8b5d8832ef)
             check_type(argname="argument container_path", value=container_path, expected_type=type_hints["container_path"])
             check_type(argname="argument host_path", value=host_path, expected_type=type_hints["host_path"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "container_path": container_path,
             "host_path": host_path,
         }
@@ -151,29 +151,29 @@ class DockerVolumes:
 
 
 class GitlabRunnerAutoscaling(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdktf-gitlab-runner.GitlabRunnerAutoscaling",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         gitlab_token: builtins.str,
-        provider: cdktf_cdktf_provider_google.GoogleProvider,
+        provider: _cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider,
         automatic_restart: typing.Optional[builtins.bool] = None,
-        compute_network: typing.Optional[cdktf_cdktf_provider_google.DataGoogleComputeNetwork] = None,
+        compute_network: typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork] = None,
         concurrent: typing.Optional[jsii.Number] = None,
         default_disk_size_gb: typing.Optional[jsii.Number] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
         download_gitlab_runner_binary_url: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
         machine_type: typing.Optional[builtins.str] = None,
         network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         preemptible: typing.Optional[builtins.bool] = None,
-        service_account: typing.Optional[typing.Union[cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount, typing.Dict[str, typing.Any]]] = None,
+        service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
@@ -196,7 +196,7 @@ class GitlabRunnerAutoscaling(
         :param tags: tags for the runner. Default: - ['runner', 'gitlab', 'awscdk']
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(GitlabRunnerAutoscaling.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__033f891cb05a9b920c1fe5001270de7f0ace57003ad62a8457ef215310793c02)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitlabRunnerAutoscalingProps(
@@ -224,19 +224,19 @@ class GitlabRunnerAutoscaling(
         self,
         *,
         gitlab_token: builtins.str,
-        provider: cdktf_cdktf_provider_google.GoogleProvider,
+        provider: _cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider,
         automatic_restart: typing.Optional[builtins.bool] = None,
-        compute_network: typing.Optional[cdktf_cdktf_provider_google.DataGoogleComputeNetwork] = None,
+        compute_network: typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork] = None,
         concurrent: typing.Optional[jsii.Number] = None,
         default_disk_size_gb: typing.Optional[jsii.Number] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
         download_gitlab_runner_binary_url: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
         machine_type: typing.Optional[builtins.str] = None,
         network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         preemptible: typing.Optional[builtins.bool] = None,
-        service_account: typing.Optional[typing.Union[cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount, typing.Dict[str, typing.Any]]] = None,
+        service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> typing.List[builtins.str]:
         '''
@@ -305,19 +305,19 @@ class GitlabRunnerAutoscalingProps:
         self,
         *,
         gitlab_token: builtins.str,
-        provider: cdktf_cdktf_provider_google.GoogleProvider,
+        provider: _cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider,
         automatic_restart: typing.Optional[builtins.bool] = None,
-        compute_network: typing.Optional[cdktf_cdktf_provider_google.DataGoogleComputeNetwork] = None,
+        compute_network: typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork] = None,
         concurrent: typing.Optional[jsii.Number] = None,
         default_disk_size_gb: typing.Optional[jsii.Number] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
         download_gitlab_runner_binary_url: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
         machine_type: typing.Optional[builtins.str] = None,
         network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         preemptible: typing.Optional[builtins.bool] = None,
-        service_account: typing.Optional[typing.Union[cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount, typing.Dict[str, typing.Any]]] = None,
+        service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
@@ -338,9 +338,9 @@ class GitlabRunnerAutoscalingProps:
         :param tags: tags for the runner. Default: - ['runner', 'gitlab', 'awscdk']
         '''
         if isinstance(service_account, dict):
-            service_account = cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount(**service_account)
+            service_account = _cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount(**service_account)
         if __debug__:
-            type_hints = typing.get_type_hints(GitlabRunnerAutoscalingProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__c88032eb7bd25ee0d2ad0139ad567354349b2287562f65346004517f962685e3)
             check_type(argname="argument gitlab_token", value=gitlab_token, expected_type=type_hints["gitlab_token"])
             check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
             check_type(argname="argument automatic_restart", value=automatic_restart, expected_type=type_hints["automatic_restart"])
@@ -356,7 +356,7 @@ class GitlabRunnerAutoscalingProps:
             check_type(argname="argument preemptible", value=preemptible, expected_type=type_hints["preemptible"])
             check_type(argname="argument service_account", value=service_account, expected_type=type_hints["service_account"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "gitlab_token": gitlab_token,
             "provider": provider,
         }
@@ -400,11 +400,11 @@ class GitlabRunnerAutoscalingProps:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def provider(self) -> cdktf_cdktf_provider_google.GoogleProvider:
+    def provider(self) -> _cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider:
         '''Google Cloud Provider.'''
         result = self._values.get("provider")
         assert result is not None, "Required property 'provider' is missing"
-        return typing.cast(cdktf_cdktf_provider_google.GoogleProvider, result)
+        return typing.cast(_cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider, result)
 
     @builtins.property
     def automatic_restart(self) -> typing.Optional[builtins.bool]:
@@ -420,7 +420,7 @@ class GitlabRunnerAutoscalingProps:
     @builtins.property
     def compute_network(
         self,
-    ) -> typing.Optional[cdktf_cdktf_provider_google.DataGoogleComputeNetwork]:
+    ) -> typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork]:
         '''VPC for the Gitlab Runner .
 
         :default: - A new VPC will be created.
@@ -434,7 +434,7 @@ class GitlabRunnerAutoscalingProps:
             new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', computeNetwork: computeNetwork });
         '''
         result = self._values.get("compute_network")
-        return typing.cast(typing.Optional[cdktf_cdktf_provider_google.DataGoogleComputeNetwork], result)
+        return typing.cast(typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork], result)
 
     @builtins.property
     def concurrent(self) -> typing.Optional[jsii.Number]:
@@ -545,10 +545,10 @@ class GitlabRunnerAutoscalingProps:
     @builtins.property
     def service_account(
         self,
-    ) -> typing.Optional[cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount]:
+    ) -> typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount]:
         '''The Service Account to be used by the Gitlab Runner.'''
         result = self._values.get("service_account")
-        return typing.cast(typing.Optional[cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount], result)
+        return typing.cast(typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount], result)
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[builtins.str]]:
@@ -578,3 +578,55 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__30cc7f3d151088ac92608a86463900f48e86489ed15b894a78018b8b5d8832ef(
+    *,
+    container_path: builtins.str,
+    host_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__033f891cb05a9b920c1fe5001270de7f0ace57003ad62a8457ef215310793c02(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    gitlab_token: builtins.str,
+    provider: _cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider,
+    automatic_restart: typing.Optional[builtins.bool] = None,
+    compute_network: typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork] = None,
+    concurrent: typing.Optional[jsii.Number] = None,
+    default_disk_size_gb: typing.Optional[jsii.Number] = None,
+    desired_capacity: typing.Optional[jsii.Number] = None,
+    docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
+    download_gitlab_runner_binary_url: typing.Optional[builtins.str] = None,
+    gitlab_url: typing.Optional[builtins.str] = None,
+    machine_type: typing.Optional[builtins.str] = None,
+    network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+    preemptible: typing.Optional[builtins.bool] = None,
+    service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c88032eb7bd25ee0d2ad0139ad567354349b2287562f65346004517f962685e3(
+    *,
+    gitlab_token: builtins.str,
+    provider: _cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider,
+    automatic_restart: typing.Optional[builtins.bool] = None,
+    compute_network: typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork] = None,
+    concurrent: typing.Optional[jsii.Number] = None,
+    default_disk_size_gb: typing.Optional[jsii.Number] = None,
+    desired_capacity: typing.Optional[jsii.Number] = None,
+    docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
+    download_gitlab_runner_binary_url: typing.Optional[builtins.str] = None,
+    gitlab_url: typing.Optional[builtins.str] = None,
+    machine_type: typing.Optional[builtins.str] = None,
+    network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+    preemptible: typing.Optional[builtins.bool] = None,
+    service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
